@@ -133,7 +133,7 @@ def dataframe_generator(time_list, df):
 
     for date in time_list[1:]:
         month = calendar.month_name[date.month]
-        mydict[month] = df[(df['ModifiedDate'] >= date.replace(day=1)) & (df['ModifiedDate'] <= date)]
+        mydict[month] = df[(df['ValueDate'] >= date.replace(day=1)) & (df['ValueDate'] <= date)]
     return mydict
 
 
@@ -190,7 +190,7 @@ def data_combined():
     df['financial_status'] = df.apply(financial_status, axis=1)
     df['business_line'] = df.apply(business_line, axis=1)
     df['Generalised_Name'] = df['Name'].apply(generalised_unit_name)
-    df['ModifiedDate'] = df['ValueDate'].apply(lambda x: x.date())
+    # df['ModifiedDate'] = df['ValueDate'].apply(lambda x: x.date())
 
     master_df = data_df(df)
     master_gen_df = data_df(df, gen=True)
