@@ -31,7 +31,7 @@ def blob_reader(BLOBNAME, LOCALFILENAME, text_reader=False):
 
 def read_sql(sql_conn):
     conn = pyodbc.connect(sql_conn)
-    sql_query = pd.read_sql_query("SELECT * from Tradebook", conn)
+    sql_query = pd.read_sql_query("SELECT * from Tradebook_Alex", conn)
 
     df = pd.DataFrame(sql_query, columns=['Id', 'TradeDate', 'Direction', 'TradeType', 'Status',
                                           'Name', 'Shares', 'Volume', 'SSP', 'Actual_Sale_Px', 'Instrument',
@@ -53,7 +53,6 @@ sql_connection = blob_reader('sql_connection.txt', ' ', True)
 print(f'Read from text file successful. \n{str(sql_connection)}')
 dataframe_tradebook = read_sql(str(sql_connection))
 print(f'Read from DB successful.')
-print(f"type of {dataframe_tradebook['ValueDate'].iloc[0]} is {type(dataframe_tradebook['ValueDate'].iloc[0])}")
 
 # dataframe_tradebook = blob_reader('tradebook.csv', 'tradebook.csv')
 #
